@@ -4,8 +4,6 @@ unload <- function(debug = FALSE) {
 
 api <- function() {
   list(
-    renviron   = renviron,     ## Deprecated
-    rprofile   = rprofile,     ## Deprecated
     renviron_d = renviron_d,
     rprofile_d = rprofile_d,
     unload     = unload
